from setuptools import find_packages, setup

metadata = {}
with open('radiens/version.py', 'r') as f:
    exec(f.read(), None, metadata)

with open('README.md', 'r') as f:
    long_description = f.read()
long_description += '\n\n'
with open('CHANGELOG.md', 'r') as f:
    long_description += f.read()

with open('requirements.txt', 'r') as f:
    _reqs = f.read().split('\n')
    install_requires = [r for r in _reqs if r]

setup(name='radiens',
      version=metadata['__version__'],
      description='provides python API to RADIENS analytics platform',
      long_description=long_description,
      long_description_content_type="text/markdown",
      author='NeuroNexus',
      author_email='dkipke@neuronexus.com',
      license='MIT',
      license_files=('LICENSE',),
      url='http://neuronexus.github.io',
      classifiers=[
          'Operating System :: OS Independent',
          'Programming Language :: Python :: 3.10',
          'License :: OSI Approved :: MIT License',
      ],
      packages=find_packages(exclude=('radiens_obs', 'tests')),
      include_package_data=True,
      python_requires=">=3.10,<3.13",
      install_requires=install_requires,
      entry_points={
          'console_scripts': ['radiens=radiens.cli.main:cli',
                              ]},

      )



"""
radiens CLI
"""
from datetime import datetime
from pathlib import Path
from pprint import pprint

import click
import pandas as pd
# from radiens.lib.graphics.graphics import plot_sig_metrics
from radiens.utils.constants import PRIMARY_CACHE_STREAM_GROUP_ID
from radiens.utils.enums import ClientType
from radiens.utils.util import time_now


@click.group(short_help="signal metrics commands")
@click.pass_context
def metrics(ctx):
    """
    Signal metrics commands.

    This command group has sub-commands for specifying, controlling, and accessing signal metrics.
    """


@metrics.command("clear", short_help="clear signal metrics")
@click.pass_context
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
def clear(ctx, index, dset_id, hub):
    """
    Clears the signal metrics for the requested linked dataset.

    """
    cmd_app = ClientType.parse(ctx.obj["cmd_app"])
    try:
        if cmd_app.is_videre():
            dsource = ctx.obj["videre_client"].get_data_file_metadata(
                dataset_idx=index, dataset_id=dset_id, fail_hard=True
            )
            ctx.obj["videre_client"].signal_metrics().clear(
                dataset_metadata=dsource)
            msg_id = dsource.id
        else:
            click.Echo("not implemented yet for Allego")
            msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    click.echo(
        "{} ({}) : cleared signal metrics at {}".format(
            cmd_app.name, msg_id, time_now()
        )
    )


@metrics.command("calculate", short_help="calculates signal metrics")
@click.pass_context
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-cmd",
    "--command",
    type=click.Choice(["standard", "custom"], case_sensitive=False),
    default="standard",
    help="calculate command",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
def calc(ctx, index, dset_id, command, hub):
    """
    Calculates the signal metrics for the requested linked data set.
    """
    cmd_app = ClientType.parse(ctx.obj["cmd_app"])
    try:
        if cmd_app.is_videre():
            dsource = ctx.obj["videre_client"].get_data_file_metadata(
                dataset_idx=index, dataset_id=dset_id, fail_hard=True
            )
            ctx.obj["videre_client"].signal_metrics().calculate(
                dataset_metadata=dsource,
                cmd=command,
                hub_name=hub,
            )
            msg_id = dsource.id
        else:
            click.Echo("not implemented yet for Allego")
            msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    click.echo(
        "{} ({}) : (re-)calculated signal metrics at {}".format(
            cmd_app.is_videre(), msg_id, time_now()
        )
    )


@metrics.command("status", short_help="prints the status of the signal metrics service")
@click.pass_context
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
def status(ctx, index, dset_id, hub):
    """
    Prints the status of the stream metrics service.
    """

    cmd_app = ClientType.parse(ctx.obj["cmd_app"])
    try:
        if cmd_app.is_videre():
            dsource = ctx.obj["videre_client"].get_data_file_metadata(
                dataset_idx=index, dataset_id=dset_id, fail_hard=True
            )
            resp = (
                ctx.obj["videre_client"]
                .signal_metrics()
                .get_metrics_status(dataset_metadata=dsource)
            )
            msg_id = dsource.id
        else:
            click.Echo("not implemented yet for Allego")
            msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    click.echo(
        "{} ({}) : status at {}".format(
            cmd_app.name, msg_id, time_now())
    )
    resp.print()


@metrics.command("params", short_help="prints the signal metrics parameters")
@click.pass_context
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
def params(ctx, index, dset_id, hub):
    """
    Prints the status of the stream metrics service.
    """
    cmd_app = ClientType.parse(ctx.obj["cmd_app"])
    try:
        if cmd_app.is_videre():
            dsource = ctx.obj["videre_client"].get_data_file_metadata(
                dataset_idx=index, dataset_id=dset_id, fail_hard=True
            )
            resp = (
                ctx.obj["videre_client"]
                .signal_metrics()
                .get_params(dataset_metadata=dsource)
            )
            msg_id = dsource.id
        else:
            click.Echo("not implemented yet for Allego")
            msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    click.echo(
        "{} ({}) : parameters at {}".format(
            cmd_app.name, msg_id, time_now()
        )
    )
    print(resp)


@metrics.command("plot", short_help="plots the signal metrics")
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
@click.pass_context
def plot(ctx, index, dset_id, hub):
    """
    Plots the requested signal metrics.
    """
    cmd_app = ClientType.parse(ctx.obj["cmd_app"])
    try:
        if cmd_app.is_videre():
            dsource = ctx.obj["videre_client"].get_data_file_metadata(
                dataset_idx=index, dataset_id=dset_id, fail_hard=True
            )
            resp = (
                ctx.obj["videre_client"]
                .signal_metrics()
                .get_metrics(dataset_metadata=dsource)
            )
            msg_id = dsource.id
        else:
            click.Echo("not implemented yet for Allego")
            msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    raise NotImplementedError("plotting not implemented in this package")
    # plot_sig_metrics(resp)
    click.echo(
        "{} ({}) : plotted at {}".format(
            cmd_app.name, msg_id, time_now())
    )


@metrics.group("set", short_help="sets the mutable signal metrics settings")
@click.pass_context
def metrics_set(ctx):
    """
    Sets signal metrics settings.

    This command group has sub-commands to set various signal metrics settings
    """


@metrics_set.command(
    "threshold", short_help="sets event threshold level(s) and activation state"
)
@click.pass_context
@click.option(
    "-nl",
    "--neg_thr_level",
    type=click.FLOAT,
    default=None,
    help="negative threshold level",
    show_default=True,
)
@click.option(
    "-pl",
    "--pos_thr_level",
    type=click.FLOAT,
    default=None,
    help="positive threshold level",
    show_default=True,
)
@click.option(
    "-s",
    "--scale",
    type=click.Choice(["uV", "sd"], case_sensitive=False),
    default="uV",
    help="threshold scale in uV or SD",
    show_default=True,
)
@click.option(
    "-na",
    "--neg_thr_act",
    type=click.BOOL,
    default=None,
    help="negative threshold activation state",
    show_default=True,
)
@click.option(
    "-pa",
    "--pos_thr_act",
    type=click.BOOL,
    default=None,
    help="positive threshold activation state",
    show_default=True,
)
@click.option(
    "-i",
    "--idxs",
    type=click.INT,
    default=None,
    help="requested channels (-1-> all channels)",
    show_default=True,
)
@click.option(
    "-w",
    "--weak_thr",
    type=click.BOOL,
    default=False,
    help="use True to set the weak threshold",
    show_default=True,
)
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
def metrics_set_threshold(
    ctx,
    neg_thr_level,
    pos_thr_level,
    scale,
    neg_thr_act,
    pos_thr_act,
    idxs,
    weak_thr,
    index,
    dset_id,
    hub,
):
    """
    Sets threshold levels and activation states
    """
    msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    idxs = None if idxs == -1 else idxs
    try:
        level_msg = (
            ctx.obj["allego_client"]
            .spike_sorter()
            .set_threshold_level(
                neg_thr=neg_thr_level,
                pos_thr=pos_thr_level,
                scale=scale,
                ntv_idxs=idxs,
                weak_thr=weak_thr,
                channel_meta=None,
            )
        )
        activate_msg = (
            ctx.obj["allego_client"]
            .spike_sorter()
            .set_threshold(
                neg_thr=neg_thr_act,
                pos_thr=pos_thr_act,
                ntv_idxs=idxs,
                weak_thr=weak_thr,
                channel_meta=None,
            )
        )
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    click.echo(
        "{} ({}) : set thresholds at {}".format(
            ctx.obj["cmd_app"].upper(), msg_id, time_now()
        )
    )
    click.echo("set thresholds : {}".format(level_msg))
    click.echo("                 {}".format(activate_msg))


@metrics_set.command("window", short_help="sets event detection window")
@click.pass_context
@click.option(
    "-pre",
    "--pre_thr_ms",
    type=click.FLOAT,
    default=None,
    help="pre-threshold time [ms]",
    show_default=True,
)
@click.option(
    "-pl",
    "--post_thr_ms",
    type=click.FLOAT,
    default=None,
    help="post-threshold time [ms]",
    show_default=True,
)
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
def metrics_set_window(ctx, pre_thr_ms, post_thr_ms, index, dset_id, hub):
    """
    Sets the event detection window
    """

    msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    try:
        msg = (
            ctx.obj["allego_client"]
            .spike_sorter()
            .set_spike_window(pre_thr_ms=pre_thr_ms, post_thr_ms=post_thr_ms)
        )
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    click.echo(
        "{} ({}) : set window at {}".format(
            ctx.obj["cmd_app"].upper(), msg_id, time_now()
        )
    )
    click.echo("set window  : {}".format(msg))


@metrics_set.command("shadow", short_help="sets shadow window")
@click.pass_context
@click.option(
    "-s",
    "--shadow_ms",
    type=click.FLOAT,
    default=None,
    help="shadow  time [ms]",
    show_default=True,
)
@click.option(
    "-idx",
    "--index",
    type=click.INT,
    default=None,
    help="dataset index from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-id",
    "--dset_id",
    type=click.STRING,
    default=None,
    help="dataset ID from table (Allego n/a)",
    show_default=True,
)
@click.option(
    "-h",
    "--hub",
    type=click.STRING,
    default="default",
    help="Radiens hub (Allego n/a)",
    show_default=True,
)
def metrics_set_shadow(ctx, shadow_ms, index, dset_id, hub):
    """
    Sets the event detection shadow window
    """
    msg_id = PRIMARY_CACHE_STREAM_GROUP_ID
    cmd_app = ClientType.parse(ctx.obj["cmd_app"])
    try:
        msg = (
            ctx.obj["allego_client"]
            .spike_sorter()
            .set_spike_shadow(shadow_ms=shadow_ms)
        )
    except Exception as ex:
        click.echo("Error: {}".format(ex))
        return
    click.echo(
        "{} ({}) : set shadow windowq at {}".format(
            cmd_app.name, msg_id, time_now()
        )
    )
    click.echo("set shadow  : {}".format(msg))



from typing import Tuple

from numpy import ndarray
from radiens.api import api_allego
from radiens.lib.allego_lib import AllegoState
from radiens.lib.channel_metadata import ChannelMetadata
from radiens.metrics_client import MetricsClient
from radiens.spike_sorter_client import SpikeSorterClient
from radiens.spikes_client import SpikesClient
from radiens.utils.constants import (ALLEGO_CORE_ADDR, PCACHE_ADDR,
                                     PRIMARY_CACHE_STREAM_GROUP_ID)
from radiens.utils.enums import (ClientType, Port, RecordMode, StreamMode,
                                 SystemMode)
from radiens.workspace_client import WorkspaceClient


class AllegoClient:
    """
    AllegoClient implements the radiens API for data acquisition and instrument control.
    It matches and extends the functionality of the Radiens Allego UI app.
    """

    def __init__(self):
        """
        """
        self._samp_freq = None
        self._sorter = SpikeSorterClient(self)
        self._workspace = WorkspaceClient()
        self._spikes = SpikesClient(self)
        self._metrics = MetricsClient(self)

    @property
    def type(self) -> ClientType:
        """
        Returns :py:attr:`~radiens.utils.enums.ClientType.ALLEGO`
        """
        return ClientType.ALLEGO

    def workspace(self) -> WorkspaceClient:
        """
        Allego workspace API
        """
        return self._workspace

    def spike_sorter(self) -> SpikeSorterClient:
        """
        Allego spike sorter API
        """
        return self._sorter

    def spikes(self) -> SpikesClient:
        """
        Allego spikes API
        """
        return self._spikes

    def signal_metrics(self) -> MetricsClient:
        """
        Allego signal metrics API
        """
        return self._metrics

    def restart(self, mode: SystemMode | str | int) -> None:
        """
        Restarts Allego in the requested mode.  

        Valid modes: 

            - smartbox_pro, 
            - smartbox_pro_sinaps_256
            - smartbox_pro_sinaps_512
            - smartbox_pro_sinaps_1024
            - smartbox_classic
            - smartbox_sim_gen_sine
            - smartbox_sim_gen_sine_mapped
            - smartbox_sim_gen_sine_high_freq
            - smartbox_sim_gen_sine_multi_band
            - smartbox_sim_gen_spikes
            - open_ephys_usb2
            - open_ephys_usb3
            - intan_usb2
            - intan_recording_controller_1024
            - intan_recording_controller_512
            - xdaq_one_req
            - xdaq_one_stim
            - xdaq_core_req
            - xdaq_core_stim

        Returns:
            None

        Side Effect:
            Resets all settings to their initialization values in the requested mode.

        Example:
            >>> client.restart('sim-spikes')
            None
        """
        return api_allego.restart(ALLEGO_CORE_ADDR, SystemMode.parse(mode))

    # ======= getters =======

    def get_available_sensors(self) -> dict:
        """
        Gets dictionary of dictionaries of available Radiens headstage and probe models, with each model of form key=component ID, value=number of channels. 

        Returns:
            sensors (dict): has keys 'headstages' and 'probes' that map to dictionaries of the available headstage models and probe models, respectively.  

        Example: 
            >>> client.get_available_sensors()
            {'sensors': {'headstages': {'hstg__chronic_smartlink_HC16': 16, 'hstg__acute_smartlink_A64': 64, ...}, 
                        'probes': {'a2x16_10mm50_500_177': 32, 'a1x16_5mm150_177': 16, ...}}
        """
        return api_allego.get_sensors(ALLEGO_CORE_ADDR)

    def get_status(self) -> AllegoState:
        """
        Gets the status of Allego.

        Returns:
            status (~radiens.lib.allego_lib.AllegoState)

        Example: 
            >>> client.get_status().print()
            ALLEGO status:
            stream       : S_ON
                time range : [0.000, 2149.197] sec
                HW memory  : 0.0 
            recording         : R_OFF
                duration        : 0.000 sec
                file name       : allego_0__uid0906-13-55-32
                base name       : allego
                path            : /Users/akelly/sapiens/core_packages/radix/radiens_etc
                index           : 0
                file timestamp  : 0906-13-55-32


        """
        s = api_allego.get_cfg_status(ALLEGO_CORE_ADDR)
        self._samp_freq = s.sample_freq
        return s

    def get_stream_loop_dur_ms(self) -> float:
        """
        Returns the stream loop duration in milliseconds

        Notes:
            Make sure to convert this to seconds if you're using it to set the sleep time in a loop.
        """
        return api_allego.get_stream_loop_dur_ms(ALLEGO_CORE_ADDR)

    def get_channel_metadata(self) -> ChannelMetadata:
        """
        Gets the channel metadata for all connected ports

        Notes:
            All ports are scanned to detect the connected ports. 

        """
        return api_allego.get_signal_group(ALLEGO_CORE_ADDR, PRIMARY_CACHE_STREAM_GROUP_ID)

    def get_signals(self) -> Tuple[ndarray, list]:
        """
        Gets the the most recent signals since last call of itself or :py:meth:`set_time_to_cache_head`.

        Returns:
            sigarray (ndarray[numpy.float32]): raw signal data; the mapping contained in signal_group (see :py:meth:`get_channel_metadata`)
            time_range (list[float]): time range (in seconds) of sigarray

        Notes:
                Sets current time to most recent time point in signal cache.

        This should be called before the first call of :py:meth:`get_signals`. The first call of :py:meth:`get_signals` 
        will return the new signals since the last call to :py:meth:`set_time_to_cache_head` 
        """
        if self._samp_freq is None:
            s = api_allego.get_cfg_status(ALLEGO_CORE_ADDR)
            self._samp_freq = s.sample_freq

        # api.set_time_to_cache_head(PCACHE_ADDR, PRIMARY_CACHE_STREAM_GROUP_ID)

        return api_allego.get_signals(PCACHE_ADDR, PRIMARY_CACHE_STREAM_GROUP_ID, self._samp_freq)

    def get_digital_out_states(self) -> dict:
        """
        Gets digital out state.

        Returns:
            dout_state_dict (dict): has keys 'digital_outs_mode' and 'states'.

        Example:
            >>> client.get_digital_out_states()
            {'digital_outs_mode': 'manual',
            'states': [{'chan_idx': 0, 'state': True}, {'chan_idx': 1, 'state': False}]}
        """
        return api_allego.get_digital_out_states(ALLEGO_CORE_ADDR)

    def get_analog_out_settings(self) -> dict:
        """
        Gets analog out settings

        Returns:
            settings (dict): 

        Example:
            >>> client.get_analog_out_settings()
            {'dac': [
                {'amp_ntv_chan_idx': -1, 
                 'aout_ntv_chan_idx': 0, 
                 'stream': 0,
                 'stream_offset_idx': 0},
                {'amp_ntv_chan_idx': -1,
                 'aout_ntv_chan_idx': 1,
                 'stream': 0,
                 'stream_offset_idx': 0}
                 ],
            'gain': 0,
            'high_pass': {'enable': False, 'cutoff_freq': 0.0}}
        """
        return api_allego.get_dac_register(ALLEGO_CORE_ADDR)

    def get_stim_params(self) -> dict:
        """
        returns current stimulation params (see :py:meth:`set_stim_params`)

        Returns:
            stim_params (dict): a dictionary where the keys are the system channel indices and the values are dictionaries containing the stimulation parameters. Each dictionary associated with a channel will have the following key-value pairs:

                - 'enabled': stimulation enabled on channel (`bool`)
                - 'enable_amp_settle': amp settle enabled on channel (`bool`)
                - 'enable_charge_recovery': charge recovery enabled on channel (`bool`)
                - 'first_phase_amplitude_uA': Level of current in µA for the first phase of the stimulation waveform (type)
                - 'first_phase_duration_us': (`float`)
                - 'interphase_delay_us': (`float`)
                - 'maintain_amp_settle_us': (`float`) 
                - 'number_of_stim_pulses': (`int`)
                - 'post_stim_amp_settle_us': (`float`)
                - 'post_stim_charge_recovery_off_us': (`float`)
                - 'post_stim_charge_recovery_on_us': (`float`)
                - 'post_trigger_delay_us': (`float`)
                - 'pre_stim_amp_settle_us': (`float`)
                - 'pulse_or_train': (`int`)
                - 'pulse_train_period_us': (`float`)
                - 'refactory_period_ms': (`float`)
                - 'second_phase_amplitude_uA': Level of current in µA for the second phase of the stimulation waveform (type)
                - 'second_phase_duration_us': (`float`)
                - 'stim_polarity': (`int`)
                - 'stim_shape': (`int`)
                - 'stim_sys_chan_idx': (`int`)
                - 'trigger_edge_or_level': (`int`)
                - 'trigger_high_or_low': (`int`)
                - 'trigger_source_is_keypress': (`bool`)
                - 'trigger_source_idx': (`int`)


        Example:
            >>> get_stim_params()
            {6: # system idx
                {'stim_shape': 0,
                'stim_polarity': 0,
                'first_phase_duration_us': 100.0,
                'second_phase_duration_us': 100.0,
                'interphase_delay_us': 100.0,
                'first_phase_amplitude_uA': 0.0,
                'second_phase_amplitude_uA': 0.0,
                'baseline_voltage': 0.0,
                'trigger_edge_or_level': 0,
                'trigger_high_or_low': 0,
                'enabled': False,
                'post_trigger_delay_us': 0.0,
                'pulse_or_train': 0,
                'number_of_stim_pulses': 2,
                'pulse_train_period_us': 10000.0,
                'refactory_period_ms': 1.0,
                'pre_stim_amp_settle_us': 0.0,
                'post_stim_amp_settle_us': 0.0,
                'maintain_amp_settle_us': False,
                'enable_amp_settle': False,
                'post_stim_charge_recovery_on_us': 0.0,
                'post_stim_charge_recovery_off_us': 0.0,
                'enable_charge_recovery': False,
                'trigger_source_is_keypress': True,
                'trigger_source_idx': 1,
                'stim_sys_chan_idx': 6 # redundant but expected when setting stim params
                },
            {...}
        """
        return api_allego.get_stim_params(ALLEGO_CORE_ADDR)

    # ======= setters =======

    def set_sampling_freq(self, fs: float) -> None:
        """
        Sets sampling frequency.  Valid sampling frequencies: 625, 1000, 1250, 1500, 2000, 2500, 3000, 3333,
        4000, 5000, 6250, 8000, 10000, 12500, 15000, 20000, 25000, 30000

        Parameters: 
            fs (int): requested sampling frequency (samples/sec)

        Returns:
            None

        Example:
            >>> client.set_samp_freq(12500)
            None

        """
        api_allego.set_fs(ALLEGO_CORE_ADDR, fs)

    def set_analog_out_high_pass(self, cutoff_freq: float, enable=True) -> dict:
        """
        Sets the analog out hardware filter

        Parameters: 
            fs (int): requested sampling frequency (samples/sec)

        Returns:
            analog_out_settings (dict)

        Example:
            >>> client.set_dac_high_pass(500, True)
            {...}
        """
        return api_allego.set_dac_high_pass(ALLEGO_CORE_ADDR, enable, cutoff_freq)

    def set_sensor(self, port: Port | str | int, headstage_id: str, probe_id: str) -> None:
        """
        Sets a sensor (headstage paired with probe) to the requested port.

        The `headstage_id` and `probe_id` arguments are: 
          1. the labels listed in the `Allego` and `Videre` `Probe Model` UI tab.
          2. aliases in radiens.utils.HEADSTAGE_ALIAS and radiens.utils.PROBE_ALIAS  

        Parameters: 
            port (str): requested port (must be a currently connected port)
            headstage_id (str): requested headstage alias or headstage ID
            probe_id (str): requested probe alias or probe ID

        Returns:
            None

        Example:
            >>> client.set_sensor('A', 'smart-32', '4x8-32')
            None

        Notes:
            `radiens.utils.HEADSTAGE_ALIAS` and `radiens.utils.PROBE_ALIAS` are 
            an abridged set of headstage and probe aliases provided for convienence.  

        See also:
            :py:meth:`get_available_sensors()`
            :py:meth:`get_connected_ports()`

        """
        return api_allego.set_sensor(ALLEGO_CORE_ADDR, Port.parse(port), headstage_id, probe_id)

    def set_time_to_cache_head(self) -> None:
        """
        Sets current time to most recent time point in signal cache.

        This should be called before the first call of :py:meth:`get_signals`. The first call of :py:meth:`get_signals` 
        will return the new signals since the last call to :py:meth:`set_time_to_cache_head` 
        """
        return api_allego.set_time_to_cache_head(PCACHE_ADDR, PRIMARY_CACHE_STREAM_GROUP_ID)

    def set_manual_stim_trigger(self, trigger: int) -> None:
        """
        """
        api_allego.set_manual_stim_trigger(ALLEGO_CORE_ADDR, trigger)

    def set_stim_params(self, param_dict: dict) -> None:
        """
        Sets stimulation parameters to a stim channel. Any parameter not specified in the parameter `param_dict` will be kept as is, or set to default parameter, if not already set (see :py:meth:`get_stim_params`).

        Parameters: 
            param_dict: has following key-value pairs; comments are defaults:

                - 'enabled': # False
                - 'enable_amp_settle': # False
                - 'enable_charge_recovery': # False
                - 'first_phase_amplitude_uA': # 0
                - 'first_phase_duration_us': # 0
                - 'interphase_delay_us': # 0
                - 'maintain_amp_settle_us': # 0
                - 'number_of_stim_pulses': # 2
                - 'post_stim_amp_settle_us': # 0
                - 'post_stim_charge_recovery_off_us': # 0
                - 'post_stim_charge_recovery_on_us': # 0
                - 'post_trigger_delay_us': # 0
                - 'pre_stim_amp_settle_us': # 0
                - 'pulse_or_train': # 0 
                - 'pulse_train_period_us': # 0
                - 'refactory_period_ms': # 1
                - 'second_phase_amplitude_uA': # 0
                - 'second_phase_duration_us': # 0
                - 'stim_polarity': # 0
                - 'stim_shape': # 0
                - 'stim_sys_chan_idx': # 0
                - 'trigger_edge_or_level': # 0
                - 'trigger_high_or_low': # 0
                - 'trigger_source_is_keypress': # True
                - 'trigger_source_idx': # 0

        """
        return api_allego.set_stim_params(ALLEGO_CORE_ADDR, param_dict)

    def set_stim_step(self, step: int) -> None:
        api_allego.set_stim_step(ALLEGO_CORE_ADDR, step)

    def set_streaming(self, mode: str | int | bool | StreamMode) -> AllegoState:
        """
        Sets signal streaming to 'on' or 'off' 

        Parameters: 
            mode (str): requested mode, ``on`` or ``off``

         Returns:
            None

        Example:
            >>> client.set_streaming('on')
            None
        """
        api_allego.set_stream_state(ALLEGO_CORE_ADDR, StreamMode.parse(mode))

    def set_recording(self, mode: str | int | bool | RecordMode) -> AllegoState:
        """
        Sets signal recording to 'on' or 'off' 

        Parameters: 
            mode (str): requested mode, ``on`` or ``off``

        Returns:
            None

        Side Effect:
            sets streaming on if `mode=``on`` and streaming is off

        Example:
            >>> client.set_recording('on')
            `AllegoState`
        """
        api_allego.set_record_state(ALLEGO_CORE_ADDR, RecordMode.parse(mode))

    def set_recording_config(self, datasource_path: str, datasource_name: str, datasource_idx: int, is_time_stamp: bool = True) -> None:
        """
        Sets recording configuration

        Parameters: 
            datasource_path (str): path to output XDAT file set
            datasource_name (str): base name of XDAT file set
            datasource_idx (int): index number for the composed file name.
            is_time_stamp (bool): `True` to time stamp the composed file name.

        Returns:
            None

        Example:
            >>> client.set_recording_config('~/radix/data', 'my_base_name', 0, True)
            None
        """
        return api_allego.set_recording_config(ALLEGO_CORE_ADDR, datasource_name, datasource_path, datasource_idx, is_time_stamp)

    def set_digital_out_manual(self, dout1_state: bool, dout2_state: bool) -> None:
        """
        Sets digital out state.

        Parameters:
            dout1_state (bool): new dout 1 state
            dout2_state (bool): new dout 2 state

        Returns:
            None

        Example:
            >>> client.set_digital_out_manual(true, false)
            None

        """
        return api_allego.set_digital_out_manual(ALLEGO_CORE_ADDR, dout1_state, dout2_state)



"""
radiens CLI
"""
import click
from datetime import datetime
from pprint import pprint

from radiens.api.api_utils.util import launch_server
from radiens.utils.util import (time_now)
import radiens.api.api_videre as api_videre


# ===================== server sub-command set

@ click.group()
@ click.option('--hub', default='default', help='radiens hub name')
@ click.pass_context
def server(ctx, hub):
    ''' pyradiens server command set
    '''
    pprint('in pyradiens server: hub={hub}, ctx={ctx}')


@ server.command()
@ click.option('--hub', default='default', help='radiens hub name')
@ click.pass_context
def start(ctx, hub):
    ''' start radiens-py server in the background
    '''
    try:
        uid = ctx.obj['videre_client']._pyradiens_register_process(addr, hub)
    except Exception as ex:
        print('failed to launch radiens-py server: ex={}'.format(ex))
        return
    print("launched radiens-py server on {} with UID={}".format(addr, uid))

# ===================== system command set


@ click.group()
@ click.option('--hub', default='default', help='radiens hub name')
@ click.pass_context
def system(ctx, hub):
    ''' RADIENS system commands
    '''


system.add_command(server)


@ system.command()
@ click.pass_context
def diag(ctx, hub):
    ''' RADIENS system diagnostics
    '''
    pprint('in system diag: hub={hub}, ctx={ctx}')


# @ system.command()
# @ click.option('--hub', default='default', help='radiens hub name')
# @ click.pass_context
# def register(ctx, hub):
#     ''' register radiens-py with Radiens apps.
#     '''
#     try:
#         ctx.obj['videre_client'].radiens_py_register(hub)
#     except Exception as ex:
#         print('failed to register radiens-py: '+ex)
#         return
#     print("registered radiens-py with Radiens apps at "+time_now())



from .allego_client import AllegoClient
# from .lib.channel_metadata import ChannelMetadata
# from .lib.dataset_metadata import DatasetMetadata
# from .lib.signals_snapshot import SignalsSnapshot
from .curate_client import CurateClient
from .file_sys_client import FileSystemClient
from .utils.constants import *
from .version import __version__
from .videre_client import VidereClient

name = "radiens"



from collections import namedtuple

import numpy as np
import pandas as pd
from radiens.grpc_radiens import common_pb2
from radiens.utils.constants import KeyIdxs
from radiens.utils.enums import Port, SignalType, SignalUnits


def _parse_sig_units(sig_units) -> dict:
    parsed = {}
    for (sig_type_enum, sig_unit_enum) in sig_units.units.items():
        parsed[SignalType.parse(sig_type_enum)
               ] = SignalUnits.parse(sig_unit_enum)
    return parsed


class ChannelMetadata():
    '''
    Container for channel metadata.
    '''

    def __init__(self, raw: common_pb2.SignalGroup = None):
        """

        """
        self._d = {'dataset_uid': '', 'fs': 0.0, 'source_label': '',
                   'neighbor_max_radius_um': 0.0, 'signal_units': {}, 'has_discrete': False}
        if raw is not None:
            self._d = {'dataset_uid': raw.datasetUID, 'fs': raw.sampFreq, 'source_label': raw.sourceLabel,
                       'neighbor_max_radius_um': raw.neighborMaxRadius, 'signal_units': _parse_sig_units(raw.signalUnits), 'has_discrete': raw.hasDiscrete, 'has_continuous_amp': raw.hasContinuousAmp}

        self._df, self._sensor_spec = decode_grpc_message(raw)
        _df_amp = self._df[self._df['chan_type'] == SignalType.AMP]
        _df_ain = self._df[self._df['chan_type'] == SignalType.AIN]
        _df_din = self._df[self._df['chan_type'] == SignalType.DIN]
        _df_dout = self._df[self._df['chan_type'] == SignalType.DOUT]
        self._sig_map = {SignalType.AMP:
                         KeyIdxs(ntv=_df_amp['ntv_key_idx'].to_list(),
                                 dset=_df_amp['dataset_key_idx'].to_list(),
                                 sys=_df_amp['sys_key_idx'].to_list()),
                         SignalType.AIN: KeyIdxs(ntv=_df_ain['ntv_key_idx'].to_list(),
                                                 dset=_df_ain['dataset_key_idx'].to_list(
                         ),
                             sys=_df_ain['sys_key_idx'].to_list()),
                         SignalType.DIN: KeyIdxs(ntv=_df_din['ntv_key_idx'].to_list(),
                                                 dset=_df_din['dataset_key_idx'].to_list(
                         ),
                             sys=_df_din['sys_key_idx'].to_list()),
                         SignalType.DOUT: KeyIdxs(ntv=_df_dout['ntv_key_idx'].to_list(),
                                                  dset=_df_dout['dataset_key_idx'].to_list(
                         ),
                             sys=_df_dout['sys_key_idx'].to_list()),
                         }
        self._sel_sig_map = {SignalType.AMP:
                             KeyIdxs(ntv=_df_amp[_df_amp['selected'] == True]['ntv_key_idx'].to_list(),
                                     dset=_df_amp[_df_amp['selected'] ==
                                                  True]['dataset_key_idx'].to_list(),
                                     sys=_df_amp[_df_amp['selected'] == True]['sys_key_idx'].to_list()),
                             SignalType.AIN: KeyIdxs(ntv=_df_ain[_df_ain['selected'] == True]['ntv_key_idx'].to_list(),
                                                     dset=_df_ain[_df_ain['selected'] == True]['dataset_key_idx'].to_list(
                             ),
                                 sys=_df_ain[_df_ain['selected'] == True]['sys_key_idx'].to_list()),
                             SignalType.DIN: KeyIdxs(ntv=_df_din[_df_din['selected'] == True]['ntv_key_idx'].to_list(),
                                                     dset=_df_din[_df_din['selected'] == True]['dataset_key_idx'].to_list(
                             ),
                                 sys=_df_din[_df_din['selected'] == True]['sys_key_idx'].to_list()),
                             SignalType.DOUT: KeyIdxs(ntv=_df_dout[_df_dout['selected'] == True]['ntv_key_idx'].to_list(),
                                                      dset=_df_dout[_df_dout['selected'] == True]['dataset_key_idx'].to_list(
                             ),
                                 sys=_df_dout[_df_dout['selected'] == True]['sys_key_idx'].to_list()),
                             }
        self._num_sigs = {}
        self._sel_num_sigs = {}
        for stype in SignalType.all():
            self._num_sigs[stype] = len(self._sig_map[stype].ntv)
            self._sel_num_sigs[stype] = len(self._sel_sig_map[stype].ntv)

    def __repr__(self) -> str:
        return self.table.__repr__()

    @ property
    def table(self) -> pd.DataFrame:
        """
        Metadata table providing metadata on each channel (aka signal) in the dataset.
        """
        return self._df

    @ property
    def attributes(self) -> dict:
        """
        Dictionary of attributes
        """
        return self._d

    def site_positions(self, stype: SignalType) -> dict:
        self._d['']

    def index(self, stype: SignalType) -> KeyIdxs:
        """
        Signal indices by signal type and index type. All indices are zero-indexed.

        Parameters:
            stype (~radiens.utils.enums.SignalType): Signal type

        Returns:
            KeyIdxs (~radiens.utils.constants.KeyIdxs): Key index object with keys `ntv`, `dset`, `sys`

        See Also:
            :py:class:`~radiens.utils.enums.KeyIndex`


        Examples:
            >>> meta.index(SignalType.AMP)
            >>> KeyIdxs(ntv=[5,1,23,46], dset=[0,1,2,3], sys=[5,1,23,46])
            >>> meta.index(SignalType.AIN)
            >>> KeyIdxs(ntv=[3,2,0,1], dset=[0,1,2,3], sys=[35,34,32,33])  # signal has 32 AMP channels

        See Also:
            :py:class:`~radiens.utils.enums.KeyIndex`
            :py:class:`~radiens.utils.enums.SignalType`
        """
        if stype not in self._sig_map:
            raise ValueError('stype not in signal map')
        return self._sig_map[stype]

    def sel_index(self, stype: SignalType) -> KeyIdxs:
        """
        Selected signal indices by signal type and index type.

        Parameters:
            stype (~radiens.utils.enums.SignalType): Signal type


       See Also:
            :py:class:`~radiens.utils.enums.KeyIndex`
        """
        if stype not in self._sig_map:
            raise ValueError('stype not in signal map')
        return self._sel_sig_map[stype]

    def num_sigs(self, stype: SignalType) -> int:
        """
        Number of signals for the requested signal type.  
        """
        if stype not in self._num_sigs:
            raise ValueError('stype not in signal map')
        return self._num_sigs[stype]

    def sel_num_sigs(self, stype: SignalType) -> int:
        """
        Number of selected signals for the requested signal type.  
        """
        if stype not in self._num_sigs:
            raise ValueError('stype not in signal map')
        return self._sel_num_sigs[stype]

    def num_sigs_total(self) -> int:
        """
        Total number of signals 
        """
        n = 0
        for stype in SignalType.all():
            n = n + self._num_sigs[stype]
        return n

    @ property
    def num_selected_sigs_total(self) -> int:
        """
        Total number of signals 
        """
        n = 0
        for stype in SignalType.all():
            n = n + self._sel_num_sigs[stype]
        return n

    @property
    def sig_units(self) -> dict[SignalType, SignalUnits]:
        """
        Dictionary of signal units
        """
        return self._d['signal_units']

    @ property
    def sensor_spec(self) -> dict:
        """
        Dict with ports (str) as keys mapping to dicts describing headstage, site, and probe wireframe metadata
        """
        return self._sensor_spec


def decode_grpc_message(raw_grpc):
    chan_name = []
    chan_type = []
    ntv_key_idx = []
    dataset_key_idx = []
    site_num = []
    color_group_idx = []
    selected = []
    audio = []
    port = []
    site_shape = []
    site_ctr_x = []
    site_ctr_y = []
    site_ctr_z = []
    site_lim_x_min = []
    site_lim_y_min = []
    site_lim_z_min = []
    site_lim_x_max = []
    site_lim_y_max = []
    site_lim_z_max = []
    site_ctr_tcs_x = []
    site_ctr_tcs_y = []
    site_ctr_tcs_z = []
    sensor_units = []
    sys_key_idx = []
    site_area_um2 = []
    scs_to_tcs = []
    sensor_id = []
    probe_id = []
    headstage_id = []
    dataset_key_idx_abs = []
    ntv_chan_name = []
    sensor_uid = []
    if raw_grpc is not None:
        for row in raw_grpc.channels:
            chan_name.append(row.chanName)
            chan_type.append(SignalType(row.chanType))
            ntv_key_idx.append(row.ntvChanIdx)

            dataset_key_idx.append(row.datasetRidx)

            site_num.append(row.siteNum)
            color_group_idx.append(row.colorGroupIdx)
            selected.append(row.isSelected)
            audio.append([row.isAudioLeft, row.isAudioRight])
            port.append(Port._from_enum(row.port).name)
            site_shape.append(row.siteShape)
            site_ctr_x.append(row.siteCtrX)
            site_ctr_y.append(row.siteCtrY)
            site_ctr_z.append(row.siteCtrZ)
            site_lim_x_min.append(row.siteLimXMin)
            site_lim_y_min.append(row.siteLimYMin)
            site_lim_z_min.append(row.siteLimZMin)
            site_lim_x_max.append(row.siteLimXMax)
            site_lim_y_max.append(row.siteLimYMax)
            site_lim_z_max.append(row.siteLimZMax)
            site_ctr_tcs_x.append(row.siteCtrTcsX)
            site_ctr_tcs_y.append(row.siteCtrTcsY)
            site_ctr_tcs_z.append(row.siteCtrTcsZ)
            sensor_units.append(row.sensorUnits)
            sys_key_idx.append(row.absIdx)

            site_area_um2.append(row.siteAreaMicron2)
            scs_to_tcs.append([row.scsToTcsX, row.scsToTcsY, row.scsToTcsZ])
            sensor_id.append(row.sensorID)
            probe_id.append(row.probeID)
            headstage_id.append(row.headstageID)
            dataset_key_idx_abs.append(row.datasetAidx)
            ntv_chan_name.append(row.ntvChanName)
            sensor_uid.append(row.sensorUID)

    _df = pd.DataFrame({'port': port,
                        'chan_name': chan_name,
                        'chan_type': chan_type,
                        'ntv_key_idx': ntv_key_idx,
                        'site_num': site_num,
                        'color_group_idx': color_group_idx,
                        'selected': selected,
                        'audio': audio,
                        'site_shape': site_shape,
                        'site_ctr_x': site_ctr_x,
                        'site_ctr_y': site_ctr_y,
                        'site_ctr_z': site_ctr_z,
                        'site_lim_x_min': site_lim_x_min,
                        'site_lim_y_min': site_lim_y_min,
                        'site_lim_z_min': site_lim_z_min,
                        'site_lim_x_max': site_lim_x_max,
                        'site_lim_y_max': site_lim_y_max,
                        'site_lim_z_max': site_lim_z_max,
                        'site_ctr_tcs_x': site_ctr_tcs_x,
                        'site_ctr_tcs_y': site_ctr_tcs_y,
                        'site_ctr_tcs_z': site_ctr_tcs_z,
                        'sensor_units': sensor_units,
                        'sys_key_idx': sys_key_idx,
                        'site_area_um2': site_area_um2,
                        'scs_to_tcs': scs_to_tcs,
                        'sensor_id': sensor_id,
                        'probe_id': probe_id,
                        'headstage_id': headstage_id,
                        'ntv_chan_name': ntv_chan_name,
                        'sensor_uid': sensor_uid,
                        'dataset_key_idx': dataset_key_idx,
                        'dataset_key_idx_abs': dataset_key_idx_abs,
                        }).reset_index(drop=True)
    _df.index.name = 'dyn_sort_idx'

    sensor_port_spec = {}
    for port in ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H']:
        sensor_port_spec[port] = []
    if raw_grpc is not None:
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorA):
            sensor_port_spec['A'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorA[m]))
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorB):
            sensor_port_spec['B'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorB[m]))
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorC):
            sensor_port_spec['C'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorC[m]))
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorD):
            sensor_port_spec['D'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorD[m]))
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorE):
            sensor_port_spec['E'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorE[m]))
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorF):
            sensor_port_spec['F'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorF[m]))
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorG):
            sensor_port_spec['G'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorG[m]))
        for m, _ in enumerate(raw_grpc.sensorPortSpec.sensorH):
            sensor_port_spec['H'].append(decode_grpc_sensor_port_spec(
                raw_grpc.sensorPortSpec.sensorH[m]))

    return _df, sensor_port_spec


def decode_grpc_sensor_port_spec(grpc_sensor):
    d = {'probe_id': grpc_sensor.probeId,
         'headstage_id': grpc_sensor.headstageId,
         'sensor_uid': '',
         'x_min': grpc_sensor.xMin,
         'x_max': grpc_sensor.xMax,
         'y_min': grpc_sensor.yMin,
         'y_max': grpc_sensor.yMax,
         'wireframe_x': [],
         'wireframe_y': [],
         'wireframe_vtx_x_lim': 0,
         'wireframe_vtx_y_lim': 0,
         'sensor_pos': {'x': 0, 'y': 0, 'z': 0, 'ring_angle': 0, 'axial_angle': 0, 'arc_angle': 0}}
    for pt in grpc_sensor.wireframe.vtx:
        d['wireframe_x'].append(pt.x)
        d['wireframe_y'].append(pt.y)
    d['sensor_uid'] = grpc_sensor.sensorUID if grpc_sensor.sensorUID is not None else d['sensor_uid']
    d['wireframe_vtx_x_lim'] = grpc_sensor.wireframe.vtxXlim if grpc_sensor.wireframe.vtxXlim is not None else d['wireframe_vtx_x_lim']
    d['wireframe_vtx_y_lim'] = grpc_sensor.wireframe.vtxYlim if grpc_sensor.wireframe.vtxYlim is not None else d['wireframe_vtx_y_lim']

    if grpc_sensor.position is not None:
        d['sensor_pos']['x'] = grpc_sensor.position.X
        d['sensor_pos']['y'] = grpc_sensor.position.Y
        d['sensor_pos']['z'] = grpc_sensor.position.Z
        d['sensor_pos']['ring_angle'] = grpc_sensor.position.RingAngle
        d['sensor_pos']['axial_angle'] = grpc_sensor.position.AxialAngle
        d['sensor_pos']['arc_angle'] = grpc_sensor.position.ArcAngle
    return d



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: allegoserver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import datasource_pb2 as datasource__pb2
from . import biointerface_pb2 as biointerface__pb2
from . import spikesorter_pb2 as spikesorter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61llegoserver.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x10\x64\x61tasource.proto\x1a\x12\x62iointerface.proto\x1a\x11spikesorter.proto\"4\n\x0eRestartRequest\x12\"\n\x04mode\x18\x01 \x02(\x0e\x32\x14.allego.BackboneMode\":\n\x11SetProfileRequest\x12\n\n\x02id\x18\x01 \x02(\t\x12\x0c\n\x04type\x18\x02 \x02(\t\x12\x0b\n\x03\x64ur\x18\x03 \x02(\x02\"\xe9\x02\n\x10LogSystemRequest\x12\x34\n\x04mode\x18\x01 \x02(\x0e\x32&.allego.LogSystemRequest.LogSystemMode\x12=\n\x07outMode\x18\x02 \x01(\x0e\x32,.allego.LogSystemRequest.LogSystemOutputMode\x12\x16\n\x0eoutPathAndFile\x18\x03 \x01(\t\"|\n\rLogSystemMode\x12\n\n\x06\x63onfig\x10\x00\x12\n\n\x06status\x10\x01\x12\x0c\n\x08port_map\x10\x02\x12\n\n\x06pcache\x10\x03\x12\x0c\n\x08sigstats\x10\x04\x12\x11\n\rneurons_stats\x10\x06\x12\x18\n\x14\x62\x61se_signalgroup_map\x10\x07\"J\n\x13LogSystemOutputMode\x12\x12\n\x0eLOG_OUT_STDERR\x10\x00\x12\x0f\n\x0bLOG_OUT_CSV\x10\x01\x12\x0e\n\nLOG_OUT_MD\x10\x02\"4\n\x10SetStreamRequest\x12 \n\x04mode\x18\x01 \x02(\x0e\x32\x12.allego.StreamMode\"P\n\x10SetRecordRequest\x12 \n\x04mode\x18\x01 \x02(\x0e\x32\x12.allego.RecordMode\x12\x1a\n\x04port\x18\x02 \x01(\x0e\x32\x0c.allego.Port\"|\n\x14SetConfigCoreRequest\x12\x10\n\x08sampFreq\x18\x01 \x01(\x01\x12\x0f\n\x07loopDur\x18\x02 \x01(\x01\x12\x19\n\x11pcachePersistence\x18\x03 \x01(\x01\x12&\n\ncableDelay\x18\x04 \x01(\x0b\x32\x12.allego.CableDelay\"L\n\nCableDelay\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x12\n\ncableDelay\x18\x02 \x02(\x05\x12\x0e\n\x06isAuto\x18\x03 \x02(\x08\"\x90\x01\n\x0b\x43\x61\x62leDelays\x12\x39\n\x0b\x63\x61\x62leDelays\x18\x01 \x03(\x0b\x32$.allego.CableDelays.CableDelaysEntry\x1a\x46\n\x10\x43\x61\x62leDelaysEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.allego.CableDelay:\x02\x38\x01\"\xcc\x01\n\nConfigCore\x12\x1c\n\x14\x61llegoCoreServerPort\x18\x01 \x02(\t\x12\x14\n\x0c\x62\x61seSampFreq\x18\x03 \x02(\x01\x12\x17\n\x0fstreamLoopDurMs\x18\x04 \x02(\x05\x12(\n\x0b\x63\x61\x62leDelays\x18\x05 \x02(\x0b\x32\x13.allego.CableDelays\x12*\n\x0c\x62\x61\x63kboneMode\x18\x06 \x02(\x0e\x32\x14.allego.BackboneMode\x12\x1b\n\x13hasXDAQGPIOExpander\x18\x07 \x02(\x08\"\xda\x03\n\x0fRecordingStatus\x12&\n\nrecordMode\x18\x01 \x02(\x0e\x32\x12.allego.RecordMode\x12\x16\n\x0e\x61\x63tiveFileName\x18\x02 \x02(\t\x12\x10\n\x08\x64uration\x18\x03 \x02(\x01\x12\r\n\x05\x65rror\x18\x04 \x02(\t\x12+\n\x0frecordModePortA\x18\x05 \x01(\x0e\x32\x12.allego.RecordMode\x12+\n\x0frecordModePortB\x18\x06 \x01(\x0e\x32\x12.allego.RecordMode\x12+\n\x0frecordModePortC\x18\x07 \x01(\x0e\x32\x12.allego.RecordMode\x12+\n\x0frecordModePortD\x18\x08 \x01(\x0e\x32\x12.allego.RecordMode\x12+\n\x0frecordModePortE\x18\t \x01(\x0e\x32\x12.allego.RecordMode\x12+\n\x0frecordModePortF\x18\n \x01(\x0e\x32\x12.allego.RecordMode\x12+\n\x0frecordModePortG\x18\x0b \x01(\x0e\x32\x12.allego.RecordMode\x12+\n\x0frecordModePortH\x18\x0c \x01(\x0e\x32\x12.allego.RecordMode\"r\n\x0fStreamingStatus\x12&\n\nstreamMode\x18\x01 \x02(\x0e\x32\x12.allego.StreamMode\x12\x1a\n\x12primaryCacheTRange\x18\x02 \x03(\x01\x12\x1b\n\x13hardwareMemoryLevel\x18\x03 \x02(\x01\"\xda\x01\n\x0e\x42\x61\x63kboneStatus\x12*\n\tstreaming\x18\x01 \x02(\x0b\x32\x17.allego.StreamingStatus\x12*\n\trecording\x18\x02 \x02(\x0b\x32\x17.allego.RecordingStatus\x12\'\n\x05ports\x18\x03 \x03(\x0b\x32\x18.allego.PortChannelCount\x12\x13\n\x0bisConnected\x18\x04 \x02(\x08\x12\x32\n\x10gpioChannelCount\x18\x05 \x02(\x0b\x32\x18.allego.GPIOChannelCount\"\xe4\x02\n\x0f\x43onfigAndStatus\x12*\n\tstreaming\x18\x01 \x02(\x0b\x32\x17.allego.StreamingStatus\x12*\n\trecording\x18\x02 \x02(\x0b\x32\x17.allego.RecordingStatus\x12\'\n\x05ports\x18\x03 \x03(\x0b\x32\x18.allego.PortChannelCount\x12\x13\n\x0bisConnected\x18\x04 \x02(\x08\x12\x32\n\x10gpioChannelCount\x18\x05 \x02(\x0b\x32\x18.allego.GPIOChannelCount\x12\x14\n\x0c\x62\x61seSampFreq\x18\x06 \x02(\x01\x12(\n\x0b\x63\x61\x62leDelays\x18\x07 \x02(\x0b\x32\x13.allego.CableDelays\x12*\n\x0c\x62\x61\x63kboneMode\x18\x08 \x02(\x0e\x32\x14.allego.BackboneMode\x12\x1b\n\x13hasXDAQGPIOExpander\x18\t \x02(\x08\"\xd0\x01\n\x0f\x43onfigRecording\x12\x14\n\x0c\x62\x61seFileName\x18\x01 \x02(\t\x12\x14\n\x0c\x62\x61seFilePath\x18\x02 \x02(\t\x12\x15\n\rdataSourceIdx\x18\x03 \x01(\x05\x12\x11\n\ttimeStamp\x18\x04 \x01(\x08\x12\x18\n\x10splitFilesByPort\x18\x05 \x01(\x08\x12\x1b\n\x13\x66orceStartAtTStamp0\x18\x06 \x01(\x08\x12\x30\n\rrecordingType\x18\x07 \x02(\x0e\x32\x19.allego.DataRecordingType\"V\n\x14\x44IOModeEventsRequest\x12\x0f\n\x07\x63hanIdx\x18\x02 \x02(\x05\x12\x16\n\x0e\x65ventThreshold\x18\x03 \x02(\x01\x12\x15\n\reventPolarity\x18\x04 \x02(\x08\"6\n\x14\x44IOModeManualRequest\x12\x0f\n\x07\x63hanIdx\x18\x01 \x02(\x05\x12\r\n\x05state\x18\x02 \x02(\x08\",\n\x13\x44IOModeGatedRequest\x12\x15\n\rgatedPolarity\x18\x03 \x02(\x08\"s\n\x19\x44igitalOutChannelRegister\x12\x13\n\x0bmanualState\x18\x01 \x02(\x08\x12\x16\n\x0e\x65ventThreshold\x18\x02 \x02(\x01\x12\x15\n\reventPolarity\x18\x03 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x04 \x02(\x05\"\x88\x01\n\x12\x44igitalOutRegister\x12\x1d\n\x04mode\x18\x01 \x02(\x0e\x32\x0f.allego.DIOMode\x12<\n\x11\x64outChanRegisters\x18\x02 \x03(\x0b\x32!.allego.DigitalOutChannelRegister\x12\x15\n\rgatedPolarity\x18\x03 \x02(\x08\"\x1e\n\x0e\x44\x41\x43GainRequest\x12\x0c\n\x04gain\x18\x01 \x02(\x05\"9\n\x13\x44\x41\x43HighPassRegister\x12\x0e\n\x06\x65nable\x18\x01 \x02(\x08\x12\x12\n\ncutoffFreq\x18\x02 \x02(\x01\"w\n\x18\x41nalogOutChannelRegister\x12\x15\n\rPriNtvChanIdx\x18\x01 \x02(\x05\x12\x1b\n\x13\x41nalogOutNtvChanIdx\x18\x02 \x02(\x05\x12\x0e\n\x06Stream\x18\x03 \x02(\x05\x12\x17\n\x0fStreamOffsetIdx\x18\x04 \x02(\x05\"\x90\x01\n\x11\x41nalogOutRegister\x12;\n\x11\x61nalogOutChannels\x18\x01 \x03(\x0b\x32 .allego.AnalogOutChannelRegister\x12\x0c\n\x04gain\x18\x02 \x02(\x05\x12\x30\n\x0bhighpassReg\x18\x03 \x02(\x0b\x32\x1b.allego.DACHighPassRegister\"!\n\x0cSerialNumber\x12\x11\n\tserialNum\x18\x01 \x02(\t\"\x81\x01\n\x12SetSimPortsRequest\x12\x33\n\x07simPort\x18\x01 \x03(\x0b\x32\".allego.SetSimPortsRequest.SimPort\x1a\x36\n\x07SimPort\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x0f\n\x07numChan\x18\x02 \x02(\x03\"2\n\x18SetHasBNCBreakoutRequest\x12\x16\n\x0ehasBNCBreakout\x18\x01 \x02(\x08\"\'\n\x14SetMuxChannelRequest\x12\x0f\n\x07\x63hannel\x18\x01 \x02(\x03\"\'\n\x14SetPotVoltageRequest\x12\x0f\n\x07voltage\x18\x01 \x02(\x02\"!\n\x10GetADCLevelReply\x12\r\n\x05level\x18\x01 \x02(\x02\"#\n\x12SetPotRangeRequest\x12\r\n\x05range\x18\x01 \x02(\x05\"!\n\x11SetPotModeRequest\x12\x0c\n\x04mode\x18\x01 \x02(\x08\")\n\x17SetPotCellEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x02(\x08\",\n\x12ReadWireOutRequest\x12\x16\n\x0ewireOutAddress\x18\x01 \x02(\x03\"(\n\x10ReadWireOutReply\x12\x14\n\x0cwireOutValue\x18\x01 \x02(\x03\"\xc7\x02\n\x11LogsysConfigReply\x12(\n\nsystemMode\x18\x01 \x02(\x0e\x32\x14.allego.BackboneMode\x12\x14\n\x0c\x62\x61seSampFreq\x18\x02 \x02(\x01\x12\x17\n\x0fstreamLoopDurMs\x18\x03 \x02(\x05\x12\x1a\n\x12priCachePersistDur\x18\x04 \x02(\x01\x12!\n\x19priCacheStatsUpdatePeriod\x18\x05 \x02(\x01\x12\x12\n\nactiveSigs\x18\x06 \x02(\x05\x12\x10\n\x08priChans\x18\x07 \x02(\x05\x12\x10\n\x08\x61uxChans\x18\x08 \x02(\x05\x12\x10\n\x08\x64inChans\x18\t \x02(\x05\x12\x11\n\tdoutChans\x18\n \x02(\x05\x12\"\n\x08portSpec\x18\x0b \x03(\x0b\x32\x10.allego.PortInfo\x12\x19\n\x11numConnectedPorts\x18\x0c \x02(\x05\"Y\n\x08PortInfo\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\r\n\x05probe\x18\x02 \x02(\t\x12\x11\n\theadstage\x18\x03 \x02(\t\x12\x0f\n\x07numSigs\x18\x04 \x02(\x05\"c\n\x11LogsysStatusReply\x12\'\n\x07recStat\x18\x01 \x02(\x0b\x32\x16.allego.RecorderStatus\x12%\n\x07sysStat\x18\x02 \x02(\x0b\x32\x14.allego.SystemStatus\"\xba\x01\n\x0eRecorderStatus\x12&\n\nrecordMode\x18\x01 \x02(\x0e\x32\x12.allego.RecordMode\x12\x10\n\x08\x64uration\x18\x02 \x02(\x01\x12\x0c\n\x04\x62\x65ta\x18\x03 \x02(\x01\x12\x11\n\tsizeBytes\x18\x04 \x02(\x05\x12\x0c\n\x04path\x18\x05 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x06 \x02(\t\x12\x15\n\rdataSourceIdx\x18\x07 \x02(\x05\x12\x16\n\x0e\x61\x63tiveFileName\x18\x08 \x02(\t\"\x96\x03\n\x0cSystemStatus\x12&\n\nstreamMode\x18\x01 \x02(\x0e\x32\x12.allego.StreamMode\x12\x14\n\x0c\x62\x61seSampFreq\x18\x02 \x02(\x01\x12\x12\n\nnumPriSigs\x18\x03 \x02(\x05\x12\x12\n\nnumAuxSigs\x18\x04 \x02(\x05\x12\x12\n\nnumDinSigs\x18\x05 \x02(\x05\x12\x13\n\x0bnumDoutSigs\x18\x06 \x02(\x05\x12\x13\n\x0btStampRange\x18\x07 \x03(\x03\x12\x0e\n\x06tRange\x18\x08 \x03(\x01\x12\x11\n\tstreamDur\x18\t \x02(\x01\x12\x14\n\x0cmeanChunkDur\x18\n \x02(\x01\x12\x1c\n\x14meanHardwareMemLevel\x18\x0b \x02(\x02\x12\x1b\n\x13maxHardwareMemLevel\x18\x0c \x02(\x02\x12\x1b\n\x13minHardwareMemLevel\x18\r \x02(\x02\x12\x1c\n\x14lastHardwareMemLevel\x18\x0e \x02(\x02\x12\x19\n\x11meanStreamLoopDur\x18\x0f \x02(\x01\x12\x18\n\x10streamEfficiency\x18\x10 \x02(\x01\"\xd8\x02\n\x11LogsysPcacheReply\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x12\n\npersistDur\x18\x03 \x02(\x01\x12\x18\n\x10minNumDatablocks\x18\x04 \x02(\x05\x12\x11\n\tsizeBytes\x18\x05 \x02(\x03\x12 \n\x18totalDatablocksProcessed\x18\x06 \x02(\x04\x12\x16\n\x0enumTimeSamples\x18\x07 \x02(\x03\x12\x1f\n\x17\x61llTimeMeanDatablockDur\x18\x08 \x02(\x01\x12\x15\n\rnumDataBlocks\x18\t \x02(\x05\x12\x0e\n\x06tRange\x18\n \x03(\x01\x12\x0f\n\x07tsRange\x18\x0b \x03(\x03\x12\x12\n\nnumPriSigs\x18\x0c \x02(\x05\x12\x12\n\nnumAuxSigs\x18\r \x02(\x05\x12\x12\n\nnumDinSigs\x18\x0e \x02(\x05\x12\x13\n\x0bnumDoutSigs\x18\x0f \x02(\x05\"i\n\x11SetTriggerRequest\x12\'\n\x07\x63hannel\x18\x01 \x02(\x0e\x32\x16.allego.TriggerChannel\x12\x0f\n\x07\x65nabled\x18\x02 \x02(\x08\x12\x1a\n\x04port\x18\x03 \x01(\x0e\x32\x0c.allego.Port\"\\\n\x0cTriggerState\x12/\n\x0f\x65nabledChannels\x18\x01 \x03(\x0e\x32\x16.allego.TriggerChannel\x12\x1b\n\x05ports\x18\x02 \x03(\x0e\x32\x0c.allego.Port\"*\n\x12LoadAllMosiRequest\x12\x14\n\x0cregisterVals\x18\x01 \x03(\x05\"\x15\n\x13TransmitMosiRequest\"5\n\x0f\x44umpMisoRequest\x12\x10\n\x08nSamples\x18\x01 \x02(\x05\x12\x10\n\x08\x66ileName\x18\x02 \x02(\t\"\xc6\x03\n\x15SinapsStatusRegisters\x12\x18\n\x10\x63\x61librationState\x18\x01 \x02(\x08\x12\x1b\n\x13\x63\x61librationProgress\x18\x02 \x02(\x01\x12\x1d\n\x15numActivePixelsShank0\x18\x03 \x02(\x05\x12\x1d\n\x15numActivePixelsShank1\x18\x04 \x02(\x05\x12\x1d\n\x15numActivePixelsShank2\x18\x05 \x02(\x05\x12\x1d\n\x15numActivePixelsShank3\x18\x06 \x02(\x05\x12\x0f\n\x07vRefFFA\x18\x07 \x02(\x01\x12\x0f\n\x07vRefFFB\x18\x08 \x02(\x01\x12\x0f\n\x07vRefFFC\x18\t \x02(\x01\x12\x0f\n\x07vRefFFD\x18\n \x02(\x01\x12\x10\n\x08isError0\x18\x0b \x02(\x08\x12\x10\n\x08isError1\x18\x0c \x02(\x08\x12\x10\n\x08isError2\x18\r \x02(\x08\x12\x10\n\x08isError3\x18\x0e \x02(\x08\x12\x13\n\x0bhostCounter\x18\x0f \x02(\x05\x12\x13\n\x0b\x66pgaCounter\x18\x10 \x02(\x05\x12\x17\n\x0f\x66irmwareVersion\x18\x11 \x02(\t\x12\x17\n\x0fprobeGeneration\x18\x12 \x02(\x05\x12\x12\n\nprobeModel\x18\x13 \x02(\x05\"%\n\x12\x46lashSinapsRequest\x12\x0f\n\x07\x62itfile\x18\x01 \x02(\t\"3\n\x0cHALdashboard\x12#\n\x04mode\x18\x01 \x02(\x0e\x32\x15.allego.AllegoHALmode\"\xbc\x06\n\nStimParams\x12$\n\tstimShape\x18\x01 \x02(\x0e\x32\x11.allego.StimShape\x12*\n\x0cstimPolarity\x18\x02 \x02(\x0e\x32\x14.allego.StimPolarity\x12\x1a\n\x12\x66irstPhaseDuration\x18\x03 \x02(\x01\x12\x1b\n\x13secondPhaseDuration\x18\x04 \x02(\x01\x12\x17\n\x0finterphaseDelay\x18\x05 \x02(\x01\x12\x1b\n\x13\x66irstPhaseAmplitude\x18\x06 \x02(\x01\x12\x1c\n\x14secondPhaseAmplitude\x18\x07 \x02(\x01\x12\x17\n\x0f\x62\x61selineVoltage\x18\x08 \x02(\x01\x12:\n\x12triggerEdgeOrLevel\x18\n \x02(\x0e\x32\x1e.allego.StimTriggerEdgeOrLevel\x12\x36\n\x10triggerHighOrLow\x18\x0b \x02(\x0e\x32\x1c.allego.StimTriggerHighOrLow\x12\x0f\n\x07\x65nabled\x18\x0c \x02(\x08\x12\x18\n\x10postTriggerDelay\x18\r \x02(\x01\x12.\n\x0cpulseOrTrain\x18\x0e \x02(\x0e\x32\x18.allego.StimPulseOrTrain\x12\x1a\n\x12numberOfStimPulses\x18\x0f \x02(\x05\x12\x18\n\x10pulseTrainPeriod\x18\x10 \x02(\x01\x12\x18\n\x10refractoryPeriod\x18\x11 \x02(\x01\x12\x18\n\x10preStimAmpSettle\x18\x12 \x02(\x01\x12\x19\n\x11postStimAmpSettle\x18\x13 \x02(\x01\x12\x19\n\x11maintainAmpSettle\x18\x14 \x02(\x08\x12\x17\n\x0f\x65nableAmpSettle\x18\x15 \x02(\x08\x12\x1d\n\x15postStimChargeRecovOn\x18\x16 \x02(\x01\x12\x1e\n\x16postStimChargeRecovOff\x18\x17 \x02(\x01\x12\x1c\n\x14\x65nableChargeRecovery\x18\x18 \x02(\x08\x12\x1f\n\x17triggerSourceIsKeypress\x18\x19 \x02(\x08\x12\x18\n\x10triggerSourceIdx\x18\x1a \x02(\x05\x12\x16\n\x0estimSysChanIdx\x18\x1b \x02(\x05\"\x89\x01\n\x0fStimParamsReply\x12\x33\n\x06params\x18\x01 \x03(\x0b\x32#.allego.StimParamsReply.ParamsEntry\x1a\x41\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.allego.StimParams:\x02\x38\x01\">\n\x18ManualStimTriggerRequest\x12\x0f\n\x07trigger\x18\x01 \x02(\x05\x12\x11\n\ttriggerOn\x18\x02 \x02(\x08\"1\n\x1eManualStimTriggerToggleRequest\x12\x0f\n\x07trigger\x18\x01 \x02(\x05\"5\n\x0fStimStepMessage\x12\"\n\x08stimStep\x18\x01 \x02(\x0e\x32\x10.allego.StimStep*!\n\nStreamMode\x12\t\n\x05S_OFF\x10\x00\x12\x08\n\x04S_ON\x10\x01*!\n\nRecordMode\x12\t\n\x05R_OFF\x10\x00\x12\x08\n\x04R_ON\x10\x01*\x9f\x04\n\x0c\x42\x61\x63kboneMode\x12\x10\n\x0cSMARTBOX_PRO\x10\x00\x12\x19\n\x15SMARTBOX_SIM_GEN_SINE\x10\x01\x12\x1b\n\x17SMARTBOX_SIM_GEN_SPIKES\x10\x02\x12\x1b\n\x17SMARTBOX_SIM_DATASOURCE\x10\x03\x12\x13\n\x0fOPEN_EPHYS_USB3\x10\x04\x12#\n\x1fINTAN_RECORDING_CONTROLLER_1024\x10\x05\x12\x14\n\x10SMARTBOX_CLASSIC\x10\x06\x12\"\n\x1eINTAN_RECORDING_CONTROLLER_512\x10\x07\x12\x13\n\x0fOPEN_EPHYS_USB2\x10\x08\x12\x0e\n\nINTAN_USB2\x10\t\x12 \n\x1cSMARTBOX_SIM_GEN_SINE_MAPPED\x10\n\x12#\n\x1fSMARTBOX_SIM_GEN_SINE_HIGH_FREQ\x10\x0b\x12$\n SMARTBOX_SIM_GEN_SINE_MULTI_BAND\x10\x0c\x12\x1b\n\x17SMARTBOX_PRO_SINAPS_256\x10\r\x12\x1c\n\x18SMARTBOX_PRO_SINAPS_1024\x10\x0e\x12\x10\n\x0cXDAQ_ONE_REC\x10\x0f\x12\x11\n\rXDAQ_ONE_STIM\x10\x10\x12\x11\n\rXDAQ_CORE_REC\x10\x11\x12\x12\n\x0eXDAQ_CORE_STIM\x10\x12\x12\x1b\n\x17SMARTBOX_PRO_SINAPS_512\x10\x13*H\n\x11\x44\x61taRecordingType\x12\x0e\n\ncontinuous\x10\x00\x12\n\n\x06spikes\x10\x01\x12\x17\n\x13\x63ontinuousAndSpikes\x10\x02*,\n\x07\x44IOMode\x12\n\n\x06manual\x10\x00\x12\n\n\x06\x65vents\x10\x01\x12\t\n\x05gated\x10\x02*\xd8\x03\n\x0eTriggerChannel\x12\x0b\n\x07T_DIN_0\x10\x00\x12\x0b\n\x07T_DIN_1\x10\x01\x12\x0b\n\x07T_DIN_2\x10\x02\x12\x0b\n\x07T_DIN_3\x10\x03\x12\x0b\n\x07T_DIN_4\x10\x04\x12\x0b\n\x07T_DIN_5\x10\x05\x12\x0b\n\x07T_DIN_6\x10\x06\x12\x0b\n\x07T_DIN_7\x10\x07\x12\x0b\n\x07T_DIN_8\x10\x08\x12\x0b\n\x07T_DIN_9\x10\t\x12\x0c\n\x08T_DIN_10\x10\n\x12\x0c\n\x08T_DIN_11\x10\x0b\x12\x0c\n\x08T_DIN_12\x10\x0c\x12\x0c\n\x08T_DIN_13\x10\r\x12\x0c\n\x08T_DIN_14\x10\x0e\x12\x0c\n\x08T_DIN_15\x10\x0f\x12\x0c\n\x08T_DOUT_0\x10\x10\x12\x0c\n\x08T_DOUT_1\x10\x11\x12\x0c\n\x08T_DOUT_2\x10\x12\x12\x0c\n\x08T_DOUT_3\x10\x13\x12\x0c\n\x08T_DOUT_4\x10\x14\x12\x0c\n\x08T_DOUT_5\x10\x15\x12\x0c\n\x08T_DOUT_6\x10\x16\x12\x0c\n\x08T_DOUT_7\x10\x17\x12\x0c\n\x08T_DOUT_8\x10\x18\x12\x0c\n\x08T_DOUT_9\x10\x19\x12\r\n\tT_DOUT_10\x10\x1a\x12\r\n\tT_DOUT_11\x10\x1b\x12\r\n\tT_DOUT_12\x10\x1c\x12\r\n\tT_DOUT_13\x10\x1d\x12\r\n\tT_DOUT_14\x10\x1e\x12\r\n\tT_DOUT_15\x10\x1f\x12\n\n\x06T_NONE\x10 *q\n\rAllegoHALmode\x12\x11\n\rA_HAL_GENERIC\x10\x00\x12\x13\n\x0f\x41_HAL_SPIKESORT\x10\x01\x12\x14\n\x10\x41_HAL_MULTISCALE\x10\x02\x12\"\n\x1e\x41_HAL_MULTISCALE_BIDIRECTIONAL\x10\x03*W\n\tStimShape\x12\x0c\n\x08\x42IPHASIC\x10\x00\x12\x1d\n\x19\x42IPHASIC_INTERPHASE_DELAY\x10\x01\x12\r\n\tTRIPHASIC\x10\x02\x12\x0e\n\nMONOPHASIC\x10\x03*4\n\x0cStimPolarity\x12\x12\n\x0e\x43\x41THODIC_FIRST\x10\x00\x12\x10\n\x0c\x41NODIC_FIRST\x10\x01*3\n\x16StimTriggerEdgeOrLevel\x12\x0b\n\x07ST_EDGE\x10\x00\x12\x0c\n\x08ST_LEVEL\x10\x01*/\n\x14StimTriggerHighOrLow\x12\x0b\n\x07ST_HIGH\x10\x00\x12\n\n\x06ST_LOW\x10\x01*5\n\x10StimPulseOrTrain\x12\x10\n\x0cSINGLE_PULSE\x10\x00\x12\x0f\n\x0bPULSE_TRAIN\x10\x01*\x90\x02\n\x08StimStep\x12\x13\n\x0fStimStepSizeMin\x10\x00\x12\x14\n\x10StimStepSize10nA\x10\x01\x12\x14\n\x10StimStepSize20nA\x10\x02\x12\x14\n\x10StimStepSize50nA\x10\x03\x12\x15\n\x11StimStepSize100nA\x10\x04\x12\x15\n\x11StimStepSize200nA\x10\x05\x12\x15\n\x11StimStepSize500nA\x10\x06\x12\x13\n\x0fStimStepSize1uA\x10\x07\x12\x13\n\x0fStimStepSize2uA\x10\x08\x12\x13\n\x0fStimStepSize5uA\x10\t\x12\x14\n\x10StimStepSize10uA\x10\n\x12\x13\n\x0fStimStepSizeMax\x10\x0b\x32\xc1*\n\nAllegoCore\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12:\n\x07Restart\x12\x16.allego.RestartRequest\x1a\x15.allego.StandardReply\"\x00\x12\x39\n\x05\x43lose\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12J\n\x13GetRadixEnvironment\x12\x17.allego.StandardRequest\x1a\x18.allego.RadixEnvironment\"\x00\x12L\n\x10WorkspaceControl\x12\x1f.allego.WorkspaceControlRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x11GetRadiensServers\x12 .allego.GetRadiensServersRequest\x1a\x1b.allego.RadiensServersReply\"\x00\x12j\n\x1bGetStatusPollFieldsToUpdate\x12\'.allego.StatusPollFieldsToUpdateRequest\x1a .allego.StatusPollFieldsToUpdate\"\x00\x12R\n\x17GetOfflineLicenseStatus\x12\x17.allego.StandardRequest\x1a\x1c.allego.OfflineLicenseStatus\"\x00\x12\x46\n\rSetConfigCore\x12\x1c.allego.SetConfigCoreRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0fSetProfileState\x12\x19.allego.SetProfileRequest\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\x12SetConfigRecording\x12\x17.allego.ConfigRecording\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\x0eSetStreamState\x12\x18.allego.SetStreamRequest\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\x0eSetRecordState\x12\x18.allego.SetRecordRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0cSetDIOEvents\x12\x1c.allego.DIOModeEventsRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0cSetDIOManual\x12\x1c.allego.DIOModeManualRequest\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\x0bSetDIOGated\x12\x1b.allego.DIOModeGatedRequest\x1a\x15.allego.StandardReply\"\x00\x12=\n\nSetDACGain\x12\x16.allego.DACGainRequest\x1a\x15.allego.StandardReply\"\x00\x12\x41\n\x0cSetDACStream\x12\x18.allego.DACStreamRequest\x1a\x15.allego.StandardReply\"\x00\x12;\n\tSetDACOff\x12\x15.allego.DACOffRequest\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\x0eSetDACHighPass\x12\x1b.allego.DACHighPassRegister\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bSetSimPorts\x12\x1a.allego.SetSimPortsRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11SetHasBNCBreakout\x12 .allego.SetHasBNCBreakoutRequest\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\rSetMuxChannel\x12\x1c.allego.SetMuxChannelRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0fSetTriggerState\x12\x19.allego.SetTriggerRequest\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\rSetPotVoltage\x12\x1c.allego.SetPotVoltageRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bSetPotRange\x12\x1a.allego.SetPotRangeRequest\x1a\x15.allego.StandardReply\"\x00\x12@\n\nSetPotMode\x12\x19.allego.SetPotModeRequest\x1a\x15.allego.StandardReply\"\x00\x12L\n\x10SetPotCellEnable\x12\x1f.allego.SetPotCellEnableRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bSetDSPGroup\x12\x1a.allego.SetDSPGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12<\n\rSetStimParams\x12\x12.allego.StimParams\x1a\x15.allego.StandardReply\"\x00\x12\x43\n\rGetStimParams\x12\x17.allego.StandardRequest\x1a\x17.allego.StimParamsReply\"\x00\x12?\n\x0bSetStimStep\x12\x17.allego.StimStepMessage\x1a\x15.allego.StandardReply\"\x00\x12\x41\n\x0bGetStimStep\x12\x17.allego.StandardRequest\x1a\x17.allego.StimStepMessage\"\x00\x12N\n\x11ManualStimTrigger\x12 .allego.ManualStimTriggerRequest\x1a\x15.allego.StandardReply\"\x00\x12Z\n\x17ManualStimTriggerToggle\x12&.allego.ManualStimTriggerToggleRequest\x1a\x15.allego.StandardReply\"\x00\x12:\n\tGetConfig\x12\x17.allego.StandardRequest\x1a\x12.allego.ConfigCore\"\x00\x12H\n\x0cGetWorkspace\x12\x1b.allego.GetWorkspaceRequest\x1a\x19.allego.GetWorkspaceReply\"\x00\x12H\n\x12GetConfigRecording\x12\x17.allego.StandardRequest\x1a\x17.allego.ConfigRecording\"\x00\x12>\n\tGetStatus\x12\x17.allego.StandardRequest\x1a\x16.allego.BackboneStatus\"\x00\x12H\n\x12GetConfigAndStatus\x12\x17.allego.StandardRequest\x1a\x17.allego.ConfigAndStatus\"\x00\x12O\n\x13GetDataSourceParams\x12\x1c.allego.SignalGroupIDRequest\x1a\x18.allego.DataSourceParams\"\x00\x12\x42\n\x11GetIntanImpedance\x12\x18.allego.ImpedanceRequest\x1a\x11.allego.Impedance\"\x00\x12?\n\x0bGetDSPGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x10.allego.DSPGroup\"\x00\x12\x42\n\tGetDIOReg\x12\x17.allego.StandardRequest\x1a\x1a.allego.DigitalOutRegister\"\x00\x12\x41\n\tGetDACReg\x12\x17.allego.StandardRequest\x1a\x19.allego.AnalogOutRegister\"\x00\x12<\n\tGetSerial\x12\x17.allego.StandardRequest\x1a\x14.allego.SerialNumber\"\x00\x12\x42\n\x0fGetTriggerState\x12\x17.allego.StandardRequest\x1a\x14.allego.TriggerState\"\x00\x12\x42\n\x0bGetADCLevel\x12\x17.allego.StandardRequest\x1a\x18.allego.GetADCLevelReply\"\x00\x12\x45\n\x0bReadWireOut\x12\x1a.allego.ReadWireOutRequest\x1a\x18.allego.ReadWireOutReply\"\x00\x12Q\n\x0fListSensorSpecs\x12\x1e.allego.ListSensorSpecsRequest\x1a\x1c.allego.ListSensorSpecsReply\"\x00\x12N\n\x11GetSignalGroupIDs\x12\x17.allego.StandardRequest\x1a\x1e.allego.GetSignalGroupIDsReply\"\x00\x12H\n\x0eGetSorterIDMap\x12\x17.allego.StandardRequest\x1a\x1b.allego.GetSorterIDMapReply\"\x00\x12N\n\x11GetSpikeSorterIDs\x12\x17.allego.StandardRequest\x1a\x1e.allego.GetSpikeSorterIDsReply\"\x00\x12\x45\n\x0eGetSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x13.allego.SignalGroup\"\x00\x12N\n\x11UpdateSignalGroup\x12 .allego.UpdateSignalGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12;\n\tScanPorts\x12\x17.allego.StandardRequest\x1a\x13.allego.SignalGroup\"\x00\x12>\n\tSetSensor\x12\x18.allego.SetSensorRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x14SetSensorPositionTcs\x12#.allego.SetSensorPositionTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SetSitePositionsTcs\x12\".allego.SetSitePositionsTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12O\n\x13GetDataSourceStatus\x12\x1c.allego.SignalGroupIDRequest\x1a\x18.allego.DataSourceStatus\"\x00\x12H\n\x0c\x46\x65\x61tureStart\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12G\n\x0b\x46\x65\x61tureStop\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12=\n\nGetPrivacy\x12\x17.allego.StandardRequest\x1a\x14.allego.PrivacyReply\"\x00\x12@\n\nSetPrivacy\x12\x19.allego.SetPrivacyRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0bLoadAllMosi\x12\x1a.allego.LoadAllMosiRequest\x1a\x15.allego.StandardReply\"\x00\x12\x44\n\x0cTransmitMosi\x12\x1b.allego.TransmitMosiRequest\x1a\x15.allego.StandardReply\"\x00\x12<\n\x08\x44umpMiso\x12\x17.allego.DumpMisoRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x18GetSinapsStatusRegisters\x12\x17.allego.StandardRequest\x1a\x1d.allego.SinapsStatusRegisters\"\x00\x12\x42\n\x0b\x46lashSinaps\x12\x1a.allego.FlashSinapsRequest\x1a\x15.allego.StandardReply\"\x00\x12L\n\x16GetOrCreateEventViewer\x12\x15.allego.EventViewerID\x1a\x19.allego.EventViewerConfig\"\x00\x12G\n\x11UpdateEventViewer\x12\x19.allego.EventViewerConfig\x1a\x15.allego.StandardReply\"\x00\x12T\n\x15ListEventViewerEvents\x12\x15.allego.EventViewerID\x1a\".allego.ListEventViewerEventsReply\"\x00\x12U\n\x13GetEventViewerEvent\x12\".allego.GetEventViewerEventRequest\x1a\x18.allego.EventViewerEvent\"\x00\x12L\n\x10ListEventViewers\x12\x17.allego.StandardRequest\x1a\x1d.allego.ListEventViewersReply\"\x00\x12\x42\n\x0fGetHALdashboard\x12\x17.allego.StandardRequest\x1a\x14.allego.HALdashboard\"\x00\x32\xe4\x02\n\x07Pcache1\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12@\n\rGetHDSnapshot\x12\x19.allego.HDSnapshotRequest\x1a\x12.allego.HDSnapshot\"\x00\x12J\n\x15GetHDSnapshotFromHead\x12\x1a.allego.HDSnapshotRequest2\x1a\x13.allego.HDSnapshot2\"\x00\x12=\n\nGetSignals\x12\x19.allego.GetSignalsRequest\x1a\x12.allego.RawSignals\"\x00\x12K\n\x12SetTimeRangeToHead\x12\x1c.allego.SignalGroupIDRequest\x1a\x15.allego.StandardReply\"\x00\x32\x8d\x04\n\x04Kpi1\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12H\n\rKpiGetMetrics\x12\x15.allego.KpiMetricsReq\x1a\x1e.allego.KpiBundlePacketMetrics\"\x00\x12\x45\n\x0cGetKpiStatus\x12\x1b.allego.GetKpiStatusRequest\x1a\x16.allego.KpiStatusReply\"\x00\x12K\n\x0bSetKpiParam\x12#.allego.SpikeSorterSetParamsRequest\x1a\x15.allego.StandardReply\"\x00\x12S\n\x0bGetKpiParam\x12\x19.allego.DataSourceRequest\x1a\'.allego.GetSpikeSorterParamCommandReply\"\x00\x12I\n\x12SetKpiUpdatePeriod\x12\x1a.allego.SetKpiParamRequest\x1a\x15.allego.StandardReply\"\x00\x12\x46\n\x0fSetKpiPacketDur\x12\x1a.allego.SetKpiParamRequest\x1a\x15.allego.StandardReply\"\x00\x32\xf7\x0b\n\x08Neurons1\x12?\n\x0bHealthcheck\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12P\n\x12SpikeSorterCommand\x12!.allego.SpikeSorterCommandRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SpikeSorterSetParam\x12\".allego.SpikeSorterSetParamRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x14SpikeSorterSetParams\x12#.allego.SpikeSorterSetParamsRequest\x1a\x15.allego.StandardReply\"\x00\x12\x64\n\x13SpikeSorterGetParam\x12\".allego.SpikeSorterStandardRequest\x1a\'.allego.GetSpikeSorterParamCommandReply\"\x00\x12\x66\n\x16SpikeSorterIsAnyActive\x12%.allego.SpikeSorterIsAnyActiveRequest\x1a#.allego.SpikeSorterIsAnyActiveReply\"\x00\x12U\n\x13SpikeSorterGetState\x12\".allego.SpikeSorterStandardRequest\x1a\x18.allego.SpikeSorterState\"\x00\x12\x63\n\x17SpikeSorterGetDashboard\x12#.allego.SpikeSorterDashboardRequest\x1a!.allego.SpikeSorterDashboardReply\"\x00\x12i\n\x18SpikeSorterGetRasterData\x12\'.allego.SpikeSorterGetRasterDataRequest\x1a\".allego.SpikeSorterRasterDataReply\"\x00\x12j\n\x1bSpikeSorterGetFeatureParams\x12\".allego.SpikeSorterStandardRequest\x1a%.allego.SpikeSorterFeatureParamsReply\"\x00\x12\x61\n\x1a\x42iointerfaceGetSpikesDense\x12\x1e.allego.SpikesGetSpikesRequest\x1a!.allego.SpikesSpikeDataDenseReply\"\x00\x12\x66\n\x16\x42iointerfaceGetNeurons\x12%.allego.BiointerfaceGetNeuronsRequest\x1a#.allego.BiointerfaceGetNeuronsReply\"\x00\x12l\n\"BiointerfaceSeekEndSpikeTimestamps\x12\x31.allego.BiointerfaceSeekEndSpikeTimestampsRequest\x1a\x11.allego.TimeRange\"\x00\x12N\n\rSpikesGetSpec\x12\".allego.SpikeSorterStandardRequest\x1a\x17.allego.SpikesSpecReply\"\x00\x12Q\n\x0f\x42iointerfaceViz\x12\x1e.allego.BiointerfaceVizRequest\x1a\x1c.allego.BiointerfaceVizReply\"\x00\x12q\n\x15GetSpikeTrainAnalytic\x12+.allego.SpikesGetSpikeTrainAnalyticsRequest\x1a).allego.SpikesGetSpikeTrainAnalyticsReply\"\x00\x42\x15Z\x13internal/radix/grpc')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'allegoserver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\023internal/radix/grpc'
  _CABLEDELAYS_CABLEDELAYSENTRY._options = None
  _CABLEDELAYS_CABLEDELAYSENTRY._serialized_options = b'8\001'
  _STIMPARAMSREPLY_PARAMSENTRY._options = None
  _STIMPARAMSREPLY_PARAMSENTRY._serialized_options = b'8\001'
  _STREAMMODE._serialized_start=7481
  _STREAMMODE._serialized_end=7514
  _RECORDMODE._serialized_start=7516
  _RECORDMODE._serialized_end=7549
  _BACKBONEMODE._serialized_start=7552
  _BACKBONEMODE._serialized_end=8095
  _DATARECORDINGTYPE._serialized_start=8097
  _DATARECORDINGTYPE._serialized_end=8169
  _DIOMODE._serialized_start=8171
  _DIOMODE._serialized_end=8215
  _TRIGGERCHANNEL._serialized_start=8218
  _TRIGGERCHANNEL._serialized_end=8690
  _ALLEGOHALMODE._serialized_start=8692
  _ALLEGOHALMODE._serialized_end=8805
  _STIMSHAPE._serialized_start=8807
  _STIMSHAPE._serialized_end=8894
  _STIMPOLARITY._serialized_start=8896
  _STIMPOLARITY._serialized_end=8948
  _STIMTRIGGEREDGEORLEVEL._serialized_start=8950
  _STIMTRIGGEREDGEORLEVEL._serialized_end=9001
  _STIMTRIGGERHIGHORLOW._serialized_start=9003
  _STIMTRIGGERHIGHORLOW._serialized_end=9050
  _STIMPULSEORTRAIN._serialized_start=9052
  _STIMPULSEORTRAIN._serialized_end=9105
  _STIMSTEP._serialized_start=9108
  _STIMSTEP._serialized_end=9380
  _RESTARTREQUEST._serialized_start=101
  _RESTARTREQUEST._serialized_end=153
  _SETPROFILEREQUEST._serialized_start=155
  _SETPROFILEREQUEST._serialized_end=213
  _LOGSYSTEMREQUEST._serialized_start=216
  _LOGSYSTEMREQUEST._serialized_end=577
  _LOGSYSTEMREQUEST_LOGSYSTEMMODE._serialized_start=377
  _LOGSYSTEMREQUEST_LOGSYSTEMMODE._serialized_end=501
  _LOGSYSTEMREQUEST_LOGSYSTEMOUTPUTMODE._serialized_start=503
  _LOGSYSTEMREQUEST_LOGSYSTEMOUTPUTMODE._serialized_end=577
  _SETSTREAMREQUEST._serialized_start=579
  _SETSTREAMREQUEST._serialized_end=631
  _SETRECORDREQUEST._serialized_start=633
  _SETRECORDREQUEST._serialized_end=713
  _SETCONFIGCOREREQUEST._serialized_start=715
  _SETCONFIGCOREREQUEST._serialized_end=839
  _CABLEDELAY._serialized_start=841
  _CABLEDELAY._serialized_end=917
  _CABLEDELAYS._serialized_start=920
  _CABLEDELAYS._serialized_end=1064
  _CABLEDELAYS_CABLEDELAYSENTRY._serialized_start=994
  _CABLEDELAYS_CABLEDELAYSENTRY._serialized_end=1064
  _CONFIGCORE._serialized_start=1067
  _CONFIGCORE._serialized_end=1271
  _RECORDINGSTATUS._serialized_start=1274
  _RECORDINGSTATUS._serialized_end=1748
  _STREAMINGSTATUS._serialized_start=1750
  _STREAMINGSTATUS._serialized_end=1864
  _BACKBONESTATUS._serialized_start=1867
  _BACKBONESTATUS._serialized_end=2085
  _CONFIGANDSTATUS._serialized_start=2088
  _CONFIGANDSTATUS._serialized_end=2444
  _CONFIGRECORDING._serialized_start=2447
  _CONFIGRECORDING._serialized_end=2655
  _DIOMODEEVENTSREQUEST._serialized_start=2657
  _DIOMODEEVENTSREQUEST._serialized_end=2743
  _DIOMODEMANUALREQUEST._serialized_start=2745
  _DIOMODEMANUALREQUEST._serialized_end=2799
  _DIOMODEGATEDREQUEST._serialized_start=2801
  _DIOMODEGATEDREQUEST._serialized_end=2845
  _DIGITALOUTCHANNELREGISTER._serialized_start=2847
  _DIGITALOUTCHANNELREGISTER._serialized_end=2962
  _DIGITALOUTREGISTER._serialized_start=2965
  _DIGITALOUTREGISTER._serialized_end=3101
  _DACGAINREQUEST._serialized_start=3103
  _DACGAINREQUEST._serialized_end=3133
  _DACHIGHPASSREGISTER._serialized_start=3135
  _DACHIGHPASSREGISTER._serialized_end=3192
  _ANALOGOUTCHANNELREGISTER._serialized_start=3194
  _ANALOGOUTCHANNELREGISTER._serialized_end=3313
  _ANALOGOUTREGISTER._serialized_start=3316
  _ANALOGOUTREGISTER._serialized_end=3460
  _SERIALNUMBER._serialized_start=3462
  _SERIALNUMBER._serialized_end=3495
  _SETSIMPORTSREQUEST._serialized_start=3498
  _SETSIMPORTSREQUEST._serialized_end=3627
  _SETSIMPORTSREQUEST_SIMPORT._serialized_start=3573
  _SETSIMPORTSREQUEST_SIMPORT._serialized_end=3627
  _SETHASBNCBREAKOUTREQUEST._serialized_start=3629
  _SETHASBNCBREAKOUTREQUEST._serialized_end=3679
  _SETMUXCHANNELREQUEST._serialized_start=3681
  _SETMUXCHANNELREQUEST._serialized_end=3720
  _SETPOTVOLTAGEREQUEST._serialized_start=3722
  _SETPOTVOLTAGEREQUEST._serialized_end=3761
  _GETADCLEVELREPLY._serialized_start=3763
  _GETADCLEVELREPLY._serialized_end=3796
  _SETPOTRANGEREQUEST._serialized_start=3798
  _SETPOTRANGEREQUEST._serialized_end=3833
  _SETPOTMODEREQUEST._serialized_start=3835
  _SETPOTMODEREQUEST._serialized_end=3868
  _SETPOTCELLENABLEREQUEST._serialized_start=3870
  _SETPOTCELLENABLEREQUEST._serialized_end=3911
  _READWIREOUTREQUEST._serialized_start=3913
  _READWIREOUTREQUEST._serialized_end=3957
  _READWIREOUTREPLY._serialized_start=3959
  _READWIREOUTREPLY._serialized_end=3999
  _LOGSYSCONFIGREPLY._serialized_start=4002
  _LOGSYSCONFIGREPLY._serialized_end=4329
  _PORTINFO._serialized_start=4331
  _PORTINFO._serialized_end=4420
  _LOGSYSSTATUSREPLY._serialized_start=4422
  _LOGSYSSTATUSREPLY._serialized_end=4521
  _RECORDERSTATUS._serialized_start=4524
  _RECORDERSTATUS._serialized_end=4710
  _SYSTEMSTATUS._serialized_start=4713
  _SYSTEMSTATUS._serialized_end=5119
  _LOGSYSPCACHEREPLY._serialized_start=5122
  _LOGSYSPCACHEREPLY._serialized_end=5466
  _SETTRIGGERREQUEST._serialized_start=5468
  _SETTRIGGERREQUEST._serialized_end=5573
  _TRIGGERSTATE._serialized_start=5575
  _TRIGGERSTATE._serialized_end=5667
  _LOADALLMOSIREQUEST._serialized_start=5669
  _LOADALLMOSIREQUEST._serialized_end=5711
  _TRANSMITMOSIREQUEST._serialized_start=5713
  _TRANSMITMOSIREQUEST._serialized_end=5734
  _DUMPMISOREQUEST._serialized_start=5736
  _DUMPMISOREQUEST._serialized_end=5789
  _SINAPSSTATUSREGISTERS._serialized_start=5792
  _SINAPSSTATUSREGISTERS._serialized_end=6246
  _FLASHSINAPSREQUEST._serialized_start=6248
  _FLASHSINAPSREQUEST._serialized_end=6285
  _HALDASHBOARD._serialized_start=6287
  _HALDASHBOARD._serialized_end=6338
  _STIMPARAMS._serialized_start=6341
  _STIMPARAMS._serialized_end=7169
  _STIMPARAMSREPLY._serialized_start=7172
  _STIMPARAMSREPLY._serialized_end=7309
  _STIMPARAMSREPLY_PARAMSENTRY._serialized_start=7244
  _STIMPARAMSREPLY_PARAMSENTRY._serialized_end=7309
  _MANUALSTIMTRIGGERREQUEST._serialized_start=7311
  _MANUALSTIMTRIGGERREQUEST._serialized_end=7373
  _MANUALSTIMTRIGGERTOGGLEREQUEST._serialized_start=7375
  _MANUALSTIMTRIGGERTOGGLEREQUEST._serialized_end=7424
  _STIMSTEPMESSAGE._serialized_start=7426
  _STIMSTEPMESSAGE._serialized_end=7479
  _ALLEGOCORE._serialized_start=9383
  _ALLEGOCORE._serialized_end=14824
  _PCACHE1._serialized_start=14827
  _PCACHE1._serialized_end=15183
  _KPI1._serialized_start=15186
  _KPI1._serialized_end=15711
  _NEURONS1._serialized_start=15714
  _NEURONS1._serialized_end=17241
# @@protoc_insertion_point(module_scope)
